@@ -1,5 +1,5 @@
 package Text::Password::CoreCrypt;
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 use 5.8.8;
 use Moose;
@@ -19,7 +19,12 @@ __PACKAGE__->meta->make_immutable;
 no Moose;
 
 use Carp;
-my @ascii = ( '!' .. '/', 0 .. 9, ':' .. '@', 'A'..'Z', '[' .. '`', 'a'..'z', '{' .. '~' );
+my @ascii = (
+    qw| ! " # $ % & ' ( ) * + , - . / |,
+    0 .. 9, qw( : ; < = > ? @ ),
+    'A'..'Z', qw( [ \ ] ^ _ ` ), # to void syntax highlighting -> `
+    'a'..'z', qw( { | } ~ ),
+);
 
 =encoding utf-8
 
