@@ -1,5 +1,5 @@
 package Text::Password::SHA;
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 use Moose;
 extends 'Text::Password::MD5';
@@ -101,7 +101,9 @@ override 'encrypt' => sub {
      die __PACKAGE__. " doesn't allow any Wide Characters or white spaces\n"
     if $input !~ /[!-~]/ or $input =~ /\s/;
 
-    my $salt = shift || $self->nonce();
+    my $salt;
+    do{ $salt = shift || $self->nonce() } while( $salt =~ /\$/ );
+
     return Crypt::Passwd::XS::unix_sha512_crypt( $input, $salt );
 };
 
